@@ -77,6 +77,6 @@ def main(argv=None):
     factory = partial(
         amqp.Connection, host=options.host, userid=options.username,
         password=options.password, virtual_host=options.vhost)
-    publisher = oops_amqp.Publisher(factory, options.exchange, options.key)
+    publisher = oops_amqp.Publisher(factory, options.exchange, options.key, inherit_id=True)
     repo = oops_datedir_repo.DateDirRepo(options.repo)
     repo.republish(publisher)
